package BAST::Context;

use strict;
use warnings;
use Storable ();

use BAST::Config;
use base qw/Class::Accessor/;

__PACKAGE__->mk_accessors(qw/config instance current_path path_cache/);

sub new {
  my ($self) = @_;
  my $new = bless({ }, ref $self || $self);
  my $conf_file = $ENV{'BAST_CONFIG'} || '/etc/bast/bast.conf';
  $new->config(BAST::Config->new(filename => $conf_file));
  $new->path_cache({});
  return $new;
}

sub copy {
  my ($self, $attrs) = @_;
  #my $new = bless({ %{$self} }, ref $self);
  my $new = Storable::dclone($self);
  if (ref $attrs eq 'HASH') {
    while (my ($k, $v) = each %$attrs) {
      $new->$k($v);
    }
  }
  return $new;
}

sub get_path {
  my ($self, $path) = @_;
  my $full_path = $self->resolve_path($path);
  return $self->path_cache->{$full_path}
    if exists $self->path_cache->{$full_path};

  my @map = $self->config->urlmap->map;
  my $doc;
  my $rest;
  MAP: foreach my $map (@map) {
    my $base = $map->base;
    if (($rest) = ($full_path =~ m!^${base}(.*)!)) {
      $doc = $map->process($rest);
      last MAP if $doc;
    }
  }
  die "No map for path ${full_path}" unless $doc;
  $self->path_cache->{$full_path} = $doc;
  return $doc;
}

sub resolve_path {
  my ($self, $path) = @_;
  return $path if $path =~ m!^/!;
  my ($base) = ($self->current_path() =~ m!^(.*)/[^/]*$!);
  return join('/', $base, $path);
}

1;
