package BAST::Invoke;

use strict;
use warnings;
use base qw/Class::XML/;

__PACKAGE__->element_name('invoke');
__PACKAGE__->has_child(evaluate => 'BAST::Evaluate');
__PACKAGE__->has_child(datasource => 'BAST::Datasource');
__PACKAGE__->has_attributes(qw/href/);

sub process {
  my ($self, $ctx) = @_;
  my $to_invoke;
  if ($self->evaluate) {
    $to_invoke = $self->evaluate;
  } elsif ($self->href) {
    $to_invoke = $ctx->get_path($self->href);
    my $pkg = 'BAST::'.ucfirst($to_invoke->getLocalName);
    Class::XML::cast($pkg, $to_invoke);
  } else {
    die "Invoke must have either an href attribute or <call> child";
  }
  my ($instance) = $self->datasource->process($ctx);
  my $inner_ctx = $ctx->copy({
                  instance => $instance });
  $inner_ctx->current_path($ctx->resolve_path($self->href)) if $self->href;
  return $to_invoke->process($inner_ctx, ($self->evaluate ? $ctx : ()));
}

1;
