package BAST::Resource::File;

use strict;
use warnings;
use base qw/BAST::Resource/;
use IO::File;

__PACKAGE__->has_attributes(qw/path/);

sub process {
  my ($self, $ctx) = @_;
  $self->write_file($ctx);
}

sub load_file { # Not used by default, provided for stuff that inherits from us
  my ($self, $ctx) = @_;
  my $file = $self->path;
  local $/ = undef;
  my $fh = new IO::File;
  $fh->open($file, '<')
    || die "Error: $! opening file";
  my $data = $fh->getline;
  defined $data || die "Error: $! reading data";
  $fh->close
    || die "Error: $! closing file";
  return $data;
}

sub write_file_contents {
  my ($self, $fh, $ctx) = @_;
  $fh->print($self->datasource->process($ctx)->string_value)
    || die "Error: $! writing output";
}

sub write_file {
  my ($self, $ctx) = @_;
  my $file = $self->path;
  my $fh = new IO::File;
  $fh->open($file.'.new', '>')
          || die "Error: $! opening new file";
  $self->write_file_contents($fh, $ctx);
  $fh->close
    || die "Error: $! closing new file";
  if (-e $file) {
    link($file,$file.'.old')
      || die "Error: $! linking backup to master";
    unlink($file)
      || die "Error: $! unlinking master";
  }
  link($file.'.new',$file)
    || die "Error: $! linking master to new file";
  unlink($file.'.new')
    || die "Error: $! unlinking new file";
  if (-e $file.'.old') {
    unlink($file.'.old')
      || die "Error: $! unlinking backup";
  }
}

1;
