package BAST::Resource::File::Record;

use strict;
use warnings;
use base qw/BAST::Resource::File/;

sub create_instance {
  my ($self, $attrs) = @_;
  my %parts = $self->get_parts($attrs);
  my $key = $self->attribute_value('record_key_format', $attrs);
  my $part = $self->attribute_value('record_format', $attrs);
  if (!(exists $parts{$key}) || $parts{$key} ne $part) {
    warn "$key -> $part\n";
    $parts{$key} = $part;
    $self->write_file($attrs, \%parts);
  }
}

sub get_parts {
  my ($self, $attrs) = @_;
  my $data = $self->load_file($attrs);
  my $split_re = $self->attribute_value('record_split_regex', $attrs);
  $split_re = qr/^(.*?${split_re})/;
  my $key_re = $self->attribute_value('record_key_regex', $attrs);
  $key_re = qr/($key_re)/;
  my @parts;
  while ($data =~ s/$split_re//) {
    my $part = $1;
    unless ($part =~ $key_re) {
      die "Can't match key regex $key_re against $part";
    }
    push(@parts, $1, $part);
  }
  return @parts;
}

sub write_file_contents {
  my ($self, $fh, $attrs, $parts) = @_;
  my $chunk = 0;
  foreach my $part (values %{$parts}) {
    $chunk++;
    $fh->print($part)
      || die "Error: $! writing output chunk ${chunk} (${part})";
  }
}

1;
