CREATE TABLE user (
  id int(11) NOT NULL auto_increment,
  name varchar(255) NOT NULL DEFAULT '',
  password varchar(255) NOT NULL DEFAULT '',
  security_role int(11) NOT NULL DEFAULT 3,
  INDEX security_role (security_role),
  PRIMARY KEY (id)
) Type=InnoDB;
 
CREATE TABLE user_card (
  id int(11) NOT NULL auto_increment,
  name varchar(255) NOT NULL DEFAULT '',
  user int(11) NOT NULL DEFAULT 0,
  cardholder_name varchar(255) NOT NULL DEFAULT '',
  card_number varchar(255) NOT NULL DEFAULT '',
  valid_from DATE,
  valid_to DATE,
  issue_number varchar(255) NOT NULL DEFAULT '',
  extra_code varchar(255) NOT NULL DEFAULT '',
  address_name varchar(255) NOT NULL DEFAULT '',
  address_street varchar(255) NOT NULL DEFAULT '',
  address_city varchar(255) NOT NULL DEFAULT '',
  address_state varchar(255) NOT NULL DEFAULT '',
  address_zip varchar(255) NOT NULL DEFAULT '',
  INDEX user (user),
  PRIMARY KEY (id)
) Type=InnoDB;
 
CREATE TABLE user_address (
  id int(11) NOT NULL auto_increment,
  name varchar(255) NOT NULL DEFAULT '',
  user int(11) NOT NULL DEFAULT 0,
  address_name varchar(255) NOT NULL DEFAULT '',
  address_street varchar(255) NOT NULL DEFAULT '',
  address_city varchar(255) NOT NULL DEFAULT '',
  address_state varchar(255) NOT NULL DEFAULT '',
  address_zip varchar(255) NOT NULL DEFAULT '',
  INDEX user (user),
  PRIMARY KEY (id)
) Type=InnoDB;
 
CREATE TABLE invoice (
  id int(11) NOT NULL auto_increment,
  user int(11) NOT NULL DEFAULT 0,
  reference varchar(255) NOT NULL DEFAULT '',
  created DATE,
  processed DATE,
  INDEX user (user),
  PRIMARY KEY (id)
) Type=InnoDB;
 
CREATE TABLE invoice_line (
  id int(11) NOT NULL auto_increment,
  invoice int(11) NOT NULL DEFAULT 0,
  name varchar(255) NOT NULL DEFAULT '',
  class varchar(255) NOT NULL DEFAULT '',
  item_id int(11) NOT NULL DEFAULT 0,
  unit_price DECIMAL(10,2) NOT NULL DEFAULT 0,
  quantity int(11) NOT NULL DEFAULT 0,
  tax_name varchar(255) NOT NULL DEFAULT '',
  tax_percentage varchar(255) NOT NULL DEFAULT '',
  INDEX invoice (invoice),
  PRIMARY KEY (id)
) Type=InnoDB;
 
CREATE TABLE invoice_card (
  id int(11) NOT NULL auto_increment,
  name varchar(255) NOT NULL DEFAULT '',
  invoice int(11) NOT NULL DEFAULT 0,
  cardholder_name varchar(255) NOT NULL DEFAULT '',
  card_number varchar(255) NOT NULL DEFAULT '',
  valid_from DATE,
  valid_to DATE,
  issue_number varchar(255) NOT NULL DEFAULT '',
  extra_code varchar(255) NOT NULL DEFAULT '',
  address_name varchar(255) NOT NULL DEFAULT '',
  address_street varchar(255) NOT NULL DEFAULT '',
  address_city varchar(255) NOT NULL DEFAULT '',
  address_state varchar(255) NOT NULL DEFAULT '',
  address_zip varchar(255) NOT NULL DEFAULT '',
  INDEX invoice (invoice),
  PRIMARY KEY (id)
) Type=InnoDB;
 
CREATE TABLE invoice_address (
  id int(11) NOT NULL auto_increment,
  name varchar(255) NOT NULL DEFAULT '',
  invoice int(11) NOT NULL DEFAULT 0,
  address_name varchar(255) NOT NULL DEFAULT '',
  address_street varchar(255) NOT NULL DEFAULT '',
  address_city varchar(255) NOT NULL DEFAULT '',
  address_state varchar(255) NOT NULL DEFAULT '',
  address_zip varchar(255) NOT NULL DEFAULT '',
  INDEX invoice (invoice),
  PRIMARY KEY (id)
) Type=InnoDB;
 
CREATE TABLE site (
  id int(11) NOT NULL auto_increment,
  domain varchar(255) NOT NULL DEFAULT '',
  name varchar(255) NOT NULL DEFAULT '',
  stylesheet varchar(255) NOT NULL DEFAULT '',
  background_image varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (id)
) Type=InnoDB;
 
CREATE TABLE page (
  id int(11) NOT NULL auto_increment,
  name varchar(255) NOT NULL DEFAULT '',
  page_template int(11) NOT NULL DEFAULT 0,
  url varchar(255) NOT NULL DEFAULT '',
  site int(11) NOT NULL DEFAULT 0,
  order_in_site int(11) NOT NULL DEFAULT 0,
  INDEX page_template (page_template),
  INDEX site (site),
  PRIMARY KEY (id)
) Type=InnoDB;
 
CREATE TABLE page_template (
  id int(11) NOT NULL auto_increment,
  name varchar(255) NOT NULL DEFAULT '',
  page_text_limit int(11) NOT NULL DEFAULT 0,
  page_image_limit int(11) NOT NULL DEFAULT 0,
  PRIMARY KEY (id)
) Type=InnoDB;
 
CREATE TABLE page_text (
  id int(11) NOT NULL auto_increment,
  page int(11) NOT NULL DEFAULT 0,
  order_in_page int(11) NOT NULL DEFAULT 0,
  heading varchar(255) NOT NULL DEFAULT '',
  text_style int(11) NOT NULL DEFAULT 1,
  text MEDIUMBLOB,
  INDEX page (page),
  INDEX text_style (text_style),
  PRIMARY KEY (id)
) Type=InnoDB;
 
CREATE TABLE page_image (
  id int(11) NOT NULL auto_increment,
  page int(11) NOT NULL DEFAULT 0,
  order_in_page int(11) NOT NULL DEFAULT 0,
  name varchar(255) NOT NULL DEFAULT '',
  image MEDIUMBLOB,
  image_type varchar(255) NOT NULL DEFAULT '',
  alt varchar(255) NOT NULL DEFAULT '',
  INDEX page (page),
  PRIMARY KEY (id)
) Type=InnoDB;
 
CREATE TABLE category (
  id int(11) NOT NULL auto_increment,
  name varchar(255) NOT NULL DEFAULT '',
  site int(11) NOT NULL DEFAULT 0,
  INDEX site (site),
  PRIMARY KEY (id)
) Type=InnoDB;
 
CREATE TABLE product (
  id int(11) NOT NULL auto_increment,
  name varchar(255) NOT NULL DEFAULT '',
  author int(11) NOT NULL DEFAULT 0,
  product_template int(11) NOT NULL DEFAULT 0,
  category int(11) NOT NULL DEFAULT 0,
  partner varchar(255) NOT NULL DEFAULT '',
  retail_price DECIMAL(10,2) NOT NULL DEFAULT 0,
  price DECIMAL(10,2) NOT NULL DEFAULT 0,
  isbn varchar(255) NOT NULL DEFAULT '',
  binding_type varchar(255) NOT NULL DEFAULT '',
  pages varchar(255) NOT NULL DEFAULT '',
  page_size varchar(255) NOT NULL DEFAULT '',
  illustrations varchar(255) NOT NULL DEFAULT '',
  colour_pictures varchar(255) NOT NULL DEFAULT '',
  publication_date DATE,
  published tinyint(1) NOT NULL DEFAULT 0,
  in_print tinyint(1) NOT NULL DEFAULT 0,
  weight varchar(255) NOT NULL DEFAULT '',
  INDEX author (author),
  INDEX product_template (product_template),
  INDEX category (category),
  PRIMARY KEY (id)
) Type=InnoDB;
 
CREATE TABLE product_template (
  id int(11) NOT NULL auto_increment,
  name varchar(255) NOT NULL DEFAULT '',
  product_text_limit int(11) NOT NULL DEFAULT 0,
  product_image_limit int(11) NOT NULL DEFAULT 0,
  PRIMARY KEY (id)
) Type=InnoDB;
 
CREATE TABLE product_text (
  id int(11) NOT NULL auto_increment,
  product int(11) NOT NULL DEFAULT 0,
  order_in_product int(11) NOT NULL DEFAULT 0,
  heading varchar(255) NOT NULL DEFAULT '',
  text_style int(11) NOT NULL DEFAULT 1,
  text MEDIUMBLOB,
  INDEX product (product),
  INDEX text_style (text_style),
  PRIMARY KEY (id)
) Type=InnoDB;
 
CREATE TABLE product_image (
  id int(11) NOT NULL auto_increment,
  product int(11) NOT NULL DEFAULT 0,
  order_in_product int(11) NOT NULL DEFAULT 0,
  name varchar(255) NOT NULL DEFAULT '',
  image MEDIUMBLOB,
  image_type varchar(255) NOT NULL DEFAULT '',
  alt varchar(255) NOT NULL DEFAULT '',
  INDEX product (product),
  PRIMARY KEY (id)
) Type=InnoDB;
 
CREATE TABLE author (
  id int(11) NOT NULL auto_increment,
  name varchar(255) NOT NULL DEFAULT '',
  qualifications varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (id)
) Type=InnoDB;
 
CREATE TABLE security_role (
  id int(11) NOT NULL auto_increment,
  name varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (id)
) Type=InnoDB;
 
CREATE TABLE security_action (
  id int(11) NOT NULL auto_increment,
  name varchar(255) NOT NULL DEFAULT '',
  action varchar(255) NOT NULL DEFAULT '',
  class varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (id)
) Type=InnoDB;
 
CREATE TABLE security_role_security_action (
  id int(11) NOT NULL auto_increment,
  security_role int(11) NOT NULL DEFAULT 0,
  security_action int(11) NOT NULL DEFAULT 0,
  restricted tinyint(1) NOT NULL DEFAULT 0,
  INDEX security_role (security_role),
  INDEX security_action (security_action),
  PRIMARY KEY (id)
) Type=InnoDB;
 
CREATE TABLE text_style (
  id int(11) NOT NULL auto_increment,
  name varchar(255) NOT NULL DEFAULT '',
  class varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (id)
) Type=InnoDB;
 
CREATE TABLE delivery_method (
  id int(11) NOT NULL auto_increment,
  name varchar(255) NOT NULL DEFAULT '',
  availability varchar(255) NOT NULL DEFAULT '',
  base_cost DECIMAL(10,2) NOT NULL DEFAULT 0,
  unit_cost DECIMAL(10,2) NOT NULL DEFAULT 0,
  min_cost DECIMAL(10,2) NOT NULL DEFAULT 0,
  discount_threshold DECIMAL(10,2) NOT NULL DEFAULT 0,
  discount_percentage varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (id)
) Type=InnoDB;
 
CREATE TABLE prod_raw_imp (
  id int(11) NOT NULL auto_increment,
  title varchar(255) NOT NULL DEFAULT '',
  AUTHOR varchar(255) NOT NULL DEFAULT '',
  PUBLISHER varchar(255) NOT NULL DEFAULT '',
  ISBNHARD varchar(255) NOT NULL DEFAULT '',
  PUBDATE varchar(255) NOT NULL DEFAULT '',
  BLURB MEDIUMBLOB,
  PAGES int(11) NOT NULL DEFAULT 0,
  illustration varchar(255) NOT NULL DEFAULT '',
  PAGESIZE varchar(255) NOT NULL DEFAULT '',
  BINDING1 varchar(255) NOT NULL DEFAULT '',
  ISBNSOFT varchar(255) NOT NULL DEFAULT '',
  PUBLISHED varchar(255) NOT NULL DEFAULT '',
  SALEBLURB MEDIUMBLOB,
  whitdescribe MEDIUMBLOB,
  DEFPRICE varchar(255) NOT NULL DEFAULT '',
  in_print varchar(255) NOT NULL DEFAULT '',
  partner varchar(255) NOT NULL DEFAULT '',
  colourpix varchar(255) NOT NULL DEFAULT '',
  series varchar(255) NOT NULL DEFAULT '',
  bindtype varchar(255) NOT NULL DEFAULT '',
  covertype varchar(255) NOT NULL DEFAULT '',
  authorqual varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (id)
) Type=InnoDB;
 
