use strict;
use warnings;
use Maypole::Constants;
use lib qw(/home/mdk/lib/fcb-shelliemark);

use FCB_ShellieMark::WWW;

sub FCB_ShellieMark::WWW::additional_data {
  my ($r) = shift;
  my $host = $r->{ar}->hostname;
  $r->{template_args}{hostname} = $host;
  $host =~ s/^www\.//;
  ($r->{template_args}{site}) = FCB_ShellieMark::DB::site->search(domain => $host);
  $r->{template_args}{auth_info} = $r->{auth_info};
}

sub FCB_ShellieMark::WWW::authenticate {
  my ($self, $r) = @_;
  return DECLINED if $r->table eq 'static'; # Hack to allow static pages
  #return OK unless $r->is_applicable; # Universal templates don't auth
  $r->get_user;
  $r->logout if $r->{params}{log_me_out};
  my %args = (user => $r->{user}, action => $r->action, request => $r);
  if ($r->args->[0]) {
    $args{object} = $r->model_class->retrieve($r->args->[0]);
  }
  $args{object_class} = $r->{table};
  if ($args{action} eq 'do_edit' && !(exists $args{object})) {
    $args{action} = 'do_add'; # Fixup - makes security easier
  }
  $r->{auth_info} = $r->is_allowed(%args);
  if ($r->{auth_info}{error}) {
    return $self->auth_error($r => $r->{auth_info}{error});
  }
  return OK;
}

sub FCB_ShellieMark::WWW::is_allowed {
  my ($r, %args) = @_;
  my $root = $r->config->template_root || $r->get_template_root;
  my $tt = Template->new( {
    INCLUDE_PATH => [ "${root}/_auth" ],
    PRE_PROCESS => '_pre',
    POST_PROCESS => '_post'
  } );
  #use Data::Dumper; warn "Args: ".Dumper(\%args);
  my $dummy;
  if ($tt->process($r->table, { %args, request => $r }, \$dummy)) {
    return { error => "Authentication error (type unknown)" };
      # Fail, damn you!
  }
  my $info = (ref $tt->error->info eq 'HASH' ? $tt->error->info : {});
  if ($tt->error->type eq 'bast.security.permit') {
    # Do nothing. We teh winnah!
  } elsif ($tt->error->type eq 'bast.security.deny') {
    $info->{error} ||= 'Permission Denied';
  } else {
    $info->{error} ||= 'Authentication error (type '.$tt->error->type.', info provided: '.$tt->error->info.')';
  }
  #warn "Res: ".($info->{error} || "Success");
  return $info;
}

sub FCB_ShellieMark::WWW::auth_error {
  my ($self, $r, $error) = @_;
  $r->template_args->{error} = $error;
  $r->template('login_error');
  #$r->model_class('Class::BlackHole');
  return OK;
}

sub FCB_ShellieMark::DB::product::list_cart :Exported {
  my ($self, $r) = @_;
  my @prod = map { FCB_ShellieMark::DB::product->retrieve($_->id) }
               grep { $_->quantity }
               FCB_ShellieMark::RAM::cart_line->retrieve_all;
  $r->objects(\@prod);
}

sub FCB_ShellieMark::DB::product_text::name {
  my ($self) = @_;
  my $text = $self->text;
  my $clip = 30;
  if (length $text > $clip) {
    return substr($text, 0, $clip - 3).'...';
  } else {
    return $text;
  }
}

sub FCB_ShellieMark::DB::page_text::name {
  my ($self) = @_;
  my $text = $self->text;
  my $clip = 30;
  if (length $text > $clip) {
    return substr($text, 0, $clip - 3).'...';
  } else {
    return $text;
  }
}

sub FCB_ShellieMark::DB::site::manage :Exported { }

sub Template::Plugin::Class::Proxy::moniker { ${$_[0]}->moniker; };

sub Template::Plugin::Class::Proxy::plural_moniker { ${$_[0]}->plural_moniker; };

{
  package FCB_ShellieMark::DB::user;

  sub all_columns {
    my ($self) = @_;
    my @ret = ($self->SUPER::all_columns, $self->columns('TEMP'));
    #warn "All: @ret, called by ".caller(2);
    return @ret;
  }

}

{

  FCB_ShellieMark::DB::user->columns(TEMP => qw/password_confirm/);
  push(@{FCB_ShellieMark::DB::user->__untaint_types->{printable}}, qw/password_confirm/ );

  my $trigger = sub { 
    my ($self) = @_;
    my ($u) = FCB_ShellieMark::DB::user->search({ name => $self->name });
    if ($u && !($u->id eq $self->id)) {
      die "user of that name already exists\n";
    }
    if ($self->password && ($self->password ne $self->password_confirm)) {
      die "passwords don't match\n";
    }
  };

  FCB_ShellieMark::DB::user->add_trigger(before_create => $trigger);
  FCB_ShellieMark::DB::user->add_trigger(before_update => $trigger);

}

FCB_ShellieMark::DB::product->might_have('cart_line' => 'FCB_ShellieMark::RAM::cart_line' => qw/quantity /);

{
  package FCB_ShellieMark::DB::product;

  use Time::Piece;

  sub publication_date_formatted {
    my $time_piece = Time::Piece->strptime(shift->publication_date, "%Y-%m-%d");
    return $time_piece->strftime("%d %B %Y");
  }
}

1;
